@@ -4,6 +4,7 @@ import logging
 import sys
 
 from znflow.base import (
+    CombinedConnections,
     Connection,
     FunctionFuture,
     Property,
@@ -12,6 +13,7 @@ from znflow.base import (
 )
 from znflow.graph import DiGraph
 from znflow.node import Node, nodify
+from znflow.utils import combine
 from znflow.visualize import draw
 
 __version__ = importlib.metadata.version(__name__)
@@ -26,6 +28,8 @@ __all__ = [
     "get_attribute",
     "disable_graph",
     "Property",
+    "CombinedConnections",
+    "combine",
 ]
 
 logger = logging.getLogger(__name__)
